@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: keys73.h 3175 2007-02-19 17:54:59Z roms $ */
+/* $Id$ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Livin
@@ -15,8 +15,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __TICALCS_KEYS73__
@@ -74,7 +74,7 @@
 
 
 
-#define KEY74_AreYouSure			0x2c
+#define KEY73_AreYouSure			0x2c
 #define KEY73_Prgm                  0x2D
 #define KEY73_Zoom                  0x2E
 #define KEY73_Draw                  0x2F
@@ -445,148 +445,148 @@
 
 #define KE2BT						(0xfe00+95)
 
-#define KEY73_Seqential			   kE2BT
-#define KEY73_SimulG               kE2BT+1  
-#define KEY73_CoordOn              kE2BT+2  
-#define KEY73_CoordOff             kE2BT+3  
-#define KEY73_DrawLine             kE2BT+4  
-#define KEY73_DrawDot              kE2BT+5  
-#define KEY73_AxisOn               kE2BT+6  
-#define KEY73_AxisOff              kE2BT+7  
-#define KEY73_GridOn               kE2BT+8  
-#define KEY73_GridOff              kE2BT+9  
-#define KEY73_LblOn                kE2BT+10 
-#define KEY73_OblOff               kE2BT+11 
-#define KEY73_PolarG               kE2BT+12 
-#define KEY73_RectG                kE2BT+13 
+#define KEY73_Seqential            0xfe5f
+#define KEY73_SimulG               0xfe60
+#define KEY73_CoordOn              0xfe61
+#define KEY73_CoordOff             0xfe62
+#define KEY73_DrawLine             0xfe63
+#define KEY73_DrawDot              0xfe64
+#define KEY73_AxisOn               0xfe65
+#define KEY73_AxisOff              0xfe66
+#define KEY73_GridOn               0xfe67
+#define KEY73_GridOff              0xfe68
+#define KEY73_LblOn                0xfe69
+#define KEY73_OblOff               0xfe6a
+#define KEY73_PolarG               0xfe6b
+#define KEY73_RectG                0xfe6c
 
-#define KEY73_L1                   kE2BT+14 
-#define KEY73_L2                   kE2BT+15
-#define KEY73_L3                   kE2BT+16
-#define KEY73_L4                   kE2BT+17
-#define KEY73_L5                   kE2BT+18
-#define KEY73_L6                   kE2BT+19
+#define KEY73_L1                   0xfe6d
+#define KEY73_L2                   0xfe6e
+#define KEY73_L3                   0xfe6f
+#define KEY73_L4                   0xfe70
+#define KEY73_L5                   0xfe71
+#define KEY73_L6                   0xfe72
 
-#define KEY73_MatA                 kE2BT+20
-#define KEY73_MatB                 kE2BT+21
-#define KEY73_MatC                 kE2BT+22
-#define KEY73_MatD                 kE2BT+23
-#define KEY73_MatE                 kE2BT+24
+#define KEY73_MatA                 0xfe73
+#define KEY73_MatB                 0xfe74
+#define KEY73_MatC                 0xfe75
+#define KEY73_MatD                 0xfe76
+#define KEY73_MatE                 0xfe77
 
-#define KEY73_Xmin                 kE2BT+25
-#define KEY73_Xmax                 kE2BT+26
-#define KEY73_Xscl                 kE2BT+27
-#define KEY73_Ymin                 kE2BT+28
-#define KEY73_Ymax                 kE2BT+29
-#define KEY73_Yscl                 kE2BT+30
-#define KEY73_Tmin                 kE2BT+31
-#define KEY73_Tmax                 kE2BT+32
-#define KEY73_TStep                kE2BT+33
-#define KEY73_Omin                 kE2BT+34
-#define KEY73_Omax                 kE2BT+35
-#define KEY73_OStep                kE2BT+36
-#define KEY73_u0                   kE2BT+37
-#define KEY73_v0                   kE2BT+38
-#define KEY73_nMin                 kE2BT+39
-#define KEY73_nMax                 kE2BT+40
-#define KEY73_DeltaY               kE2BT+41
-#define KEY73_DeltaX               kE2BT+42
+#define KEY73_Xmin                 0xfe78
+#define KEY73_Xmax                 0xfe79
+#define KEY73_Xscl                 0xfe7a
+#define KEY73_Ymin                 0xfe7b
+#define KEY73_Ymax                 0xfe7c
+#define KEY73_Yscl                 0xfe7d
+#define KEY73_Tmin                 0xfe7e
+#define KEY73_Tmax                 0xfe7f
+#define KEY73_TStep                0xfe80
+#define KEY73_Omin                 0xfe81
+#define KEY73_Omax                 0xfe82
+#define KEY73_OStep                0xfe83
+#define KEY73_u0                   0xfe84
+#define KEY73_v0                   0xfe85
+#define KEY73_nMin                 0xfe86
+#define KEY73_nMax                 0xfe87
+#define KEY73_DeltaY               0xfe88
+#define KEY73_DeltaX               0xfe89
 
-#define KEY73_ZXmin                kE2BT+43
-#define KEY73_ZXmax                kE2BT+44
-#define KEY73_ZXscl                kE2BT+45
-#define KEY73_ZYmin                kE2BT+46
-#define KEY73_ZYmax                kE2BT+47
-#define KEY73_ZYscl                kE2BT+48
-#define KEY73_ZTmin                kE2BT+49
-#define KEY73_ZTmax                kE2BT+50
-#define KEY73_ZTStep               kE2BT+51
-#define KEY73_ZOmin                kE2BT+52
-#define KEY73_ZOmax                kE2BT+53
-#define KEY73_ZOStep               kE2BT+54
+#define KEY73_ZXmin                0xfe8a
+#define KEY73_ZXmax                0xfe8b
+#define KEY73_ZXscl                0xfe8c
+#define KEY73_ZYmin                0xfe8d
+#define KEY73_ZYmax                0xfe8e
+#define KEY73_ZYscl                0xfe8f
+#define KEY73_ZTmin                0xfe90
+#define KEY73_ZTmax                0xfe91
+#define KEY73_ZTStep               0xfe92
+#define KEY73_ZOmin                0xfe93
+#define KEY73_ZOmax                0xfe94
+#define KEY73_ZOStep               0xfe95
 
-#define KEY73_ABC                  kE2BT+55
-#define KEY73_BC                   kE2BT+56
-#define KEY73_AutoSimp             kE2BT+57
-#define KEY73_ManSimp              kE2BT+58
+#define KEY73_ABC                  0xfe96
+#define KEY73_BC                   0xfe97
+#define KEY73_AutoSimp             0xfe98
+#define KEY73_ManSimp              0xfe99
 
-#define KEY73_DelLast              kE2BT+59
-#define KEY73_singleC              kE2BT+60
-#define KEY73_MultiC               kE2BT+61
+#define KEY73_DelLast              0xfe9a
+#define KEY73_singleC              0xfe9b
+#define KEY73_MultiC               0xfe9c
 
-#define KEY73_Pic1                 kE2BT+62
-#define KEY73_Pic2                 kE2BT+63
-#define KEY73_Pic3                 kE2BT+64
+#define KEY73_Pic1                 0xfe9d
+#define KEY73_Pic2                 0xfe9e
+#define KEY73_Pic3                 0xfe9f
 
-#define KEY73_DelVar               kE2BT+65
-#define KEY73_GetCalc              kE2BT+66
+#define KEY73_DelVar               0xfea0
+#define KEY73_GetCalc              0xfea1
 
-#define KEY73_Stndrd               kE2BT+67
-#define KEY73_Param                kE2BT+68
-#define KEY73_Polar                kE2BT+69
-#define KEY73_AFillOn              kE2BT+70
-#define KEY73_AFillOff             kE2BT+71
-#define KEY73_ACalcOn              kE2BT+72
-#define KEY73_ACalcOff             kE2BT+73
+#define KEY73_Stndrd               0xfea2
+#define KEY73_Param                0xfea3
+#define KEY73_Polar                0xfea4
+#define KEY73_AFillOn              0xfea5
+#define KEY73_AFillOff             0xfea6
+#define KEY73_ACalcOn              0xfea7
+#define KEY73_ACalcOff             0xfea8
 
-#define KEY73_SetConst             kE2BT+74
+#define KEY73_SetConst             0xfea9
 
-#define KEY73_GraphStyle           kE2BT+75
+#define KEY73_GraphStyle           0xfeaa
 
-#define KEY73_ExprOn               kE2BT+76
-#define KEY73_ExprOff              kE2BT+77
-#define KEY73_StatA                kE2BT+78
-#define KEY73_StatB                kE2BT+79
-#define KEY73_StatC                kE2BT+80
-#define KEY73_Corr                 kE2BT+81
-#define KEY73_StatD                kE2BT+82
-#define KEY73_StatE                kE2BT+83
-#define KEY73_RegEq                kE2BT+84
-#define KEY73_MinX                 kE2BT+85
-#define KEY73_Q1                   kE2BT+86
-#define KEY73_MD                   kE2BT+87
-#define KEY73_Q3                   kE2BT+88
-#define KEY73_MaxX                 kE2BT+89
-#define KEY73_StatX1               kE2BT+90
-#define KEY73_StatY1               kE2BT+91
-#define KEY73_StatX2               kE2BT+92
-#define KEY73_StatY2               kE2BT+93
-#define KEY73_StatX3               kE2BT+94
-#define KEY73_StatY3               kE2BT+95
-#define KEY73_TblMin               kE2BT+96
-#define KEY73_TblStep              kE2BT+97
-#define KEY73_SetupLst             kE2BT+98
-#define KEY73_ClrAllLst            kE2BT+99
-#define KEY73_Logistic             kE2BT+100
-#define KEY73_c1                   kE2BT+101   
-#define KEY73_c2                   kE2BT+102   
-#define KEY73_c3                   kE2BT+103   
-#define KEY73_c4                   kE2BT+104   
-#define KEY73_PlotStart            kE2BT+105   
-#define KEY73_ZPlotStart           kE2BT+106   
-#define KEY73_XFact                kE2BT+107   
-#define KEY73_YFact                kE2BT+108   
-#define KEY73_MaxY                 kE2BT+109   
-#define KEY73_TblInput             kE2BT+110   
-#define KEY73_PlotStep             kE2BT+111
-#define KEY73_ZPlotStep            kE2BT+112
-#define KEY73_SelectA              kE2BT+113
-#define KEY73_ZFitA                kE2BT+114
-#define KEY73_OneVar               kE2BT+115
-#define KEY73_TwoVar               kE2BT+116
-#define KEY73_LR                   kE2BT+117
-#define KEY73_LRExp                kE2BT+118
-#define KEY73_LRLn                 kE2BT+119
+#define KEY73_ExprOn               0xfeab
+#define KEY73_ExprOff              0xfeac
+#define KEY73_StatA                0xfead
+#define KEY73_StatB                0xfeae
+#define KEY73_StatC                0xfeaf
+#define KEY73_Corr                 0xfeb0
+#define KEY73_StatD                0xfeb1
+#define KEY73_StatE                0xfeb2
+#define KEY73_RegEq                0xfeb3
+#define KEY73_MinX                 0xfeb4
+#define KEY73_Q1                   0xfeb5
+#define KEY73_MD                   0xfeb6
+#define KEY73_Q3                   0xfeb7
+#define KEY73_MaxX                 0xfeb8
+#define KEY73_StatX1               0xfeb9
+#define KEY73_StatY1               0xfeba
+#define KEY73_StatX2               0xfebb
+#define KEY73_StatY2               0xfebc
+#define KEY73_StatX3               0xfebd
+#define KEY73_StatY3               0xfebe
+#define KEY73_TblMin               0xfebf
+#define KEY73_TblStep              0xfec0
+#define KEY73_SetupLst             0xfec1
+#define KEY73_ClrAllLst            0xfec2
+#define KEY73_Logistic             0xfec3
+#define KEY73_c1                   0xfec4
+#define KEY73_c2                   0xfec5
+#define KEY73_c3                   0xfec6
+#define KEY73_c4                   0xfec7
+#define KEY73_PlotStart            0xfec8
+#define KEY73_ZPlotStart           0xfec9
+#define KEY73_XFact                0xfeca
+#define KEY73_YFact                0xfecb
+#define KEY73_MaxY                 0xfecc
+#define KEY73_TblInput             0xfecd
+#define KEY73_PlotStep             0xfece
+#define KEY73_ZPlotStep            0xfecf
+#define KEY73_SelectA              0xfed0
+#define KEY73_ZFitA                0xfed1
+#define KEY73_OneVar               0xfed2
+#define KEY73_TwoVar               0xfed3
+#define KEY73_LR                   0xfed4
+#define KEY73_LRExp                0xfed5
+#define KEY73_LRLn                 0xfed6
 
 
-#define KEY73_MedMed               kE2BT+120
-#define KEY73_Quad                 kE2BT+121
-#define KEY73_ClrLst               kE2BT+122
-#define KEY73_Hist                 kE2BT+123
-#define KEY73_XYLine               kE2BT+124
-#define KEY73_Scatter              kE2BT+125
-#define KEY73_LR1                  kE2BT+126
-#define KEY73_ClrTbl               kE2BT+127
+#define KEY73_MedMed               0xfed7
+#define KEY73_Quad                 0xfed8
+#define KEY73_ClrLst               0xfed9
+#define KEY73_Hist                 0xfeda
+#define KEY73_XYLine               0xfedb
+#define KEY73_Scatter              0xfedc
+#define KEY73_LR1                  0xfedd
+#define KEY73_ClrTbl               0xfede
 
 // FC (ExtendEcho2) prefixed keys:
 
