@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: keys89.c 2385 2006-05-26 07:44:30Z roms $ */
+/* $Id$ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Livin
@@ -15,8 +15,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "ticalcs.h"
@@ -170,148 +170,148 @@ const OldCalcKeys_ TI89_KEYS[] =
   {"y", "y", 121, "Y", 89, "SIN", 4185, "SIN-1", 8281, "y", 121},
   {"z", "z", 122, "Z", 90, "COS", 4196, "COS-1", 8282, "z", 122},
   {"{", "{", 0, "", 0, "", 0, "", 0, "", 0},
-  {"|", "|", 124, "F", 70, "", 176, "d/b", 8316, "f", 102},
+  {"|", "|", 124, "F", 70, "\xb0", 176, "d/b", 8316, "f", 102}, /* Degree */
   {"}", "}", 0, "", 0, "", 0, "", 0, "", 0},
   {"~", "~", 126, "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0x80, 128 */
-  {"\128", "\128", 128, "", 0, "", 0, "", 0},
-  {"\129", "\129", 129, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"\131", "\131", 131, "\130", 130, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"\133", "\133", 133, "\132", 132, "", 0, "", 0},
-  {"\134", "\134", 134, "", 0, "", 0, "", 0},
-  {"\135", "\135", 135, "", 0, "", 0, "", 0},
+  {"\128", "\128", 128, "", 0, "", 0, "", 0, "", 0},
+  {"\129", "\129", 129, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\131", "\131", 131, "\130", 130, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\133", "\133", 133, "\132", 132, "", 0, "", 0, "", 0},
+  {"\134", "\134", 134, "", 0, "", 0, "", 0, "", 0},
+  {"\135", "\135", 135, "", 0, "", 0, "", 0, "", 0},
   {"\136", "\136", 136, "\136", 136, ":", 58, "", 8328, "", 0},
-  {"\137", "\137", 137, "", 0, "", 0, "", 0},
-  {"\138", "\138", 138, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"\140", "\140", 140, "\139", 139, "", 0, "", 0},
-  {"\141", "\141", 141, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"\143", "\143", 143, "\142", 142, "", 0, "", 0},
+  {"\137", "\137", 137, "", 0, "", 0, "", 0, "", 0},
+  {"\138", "\138", 138, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0,"", 0, "", 0},
+  {"\140", "\140", 140, "\139", 139, "", 0, "", 0, "", 0},
+  {"\141", "\141", 141, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\143", "\143", 143, "\142", 142, "", 0, "", 0, "", 0},
 /* 0x90, 144 */
-  {"\144", "\144", 144, "", 0, "", 0, "", 0},
-  {"\145", "\145", 145, "", 0, "", 0, "", 0},
-  {"\146", "\146", 146, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"\144", "\144", 144, "", 0, "", 0, "", 0, "", 0},
+  {"\145", "\145", 145, "", 0, "", 0, "", 0, "", 0},
+  {"\146", "\146", 146, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"EE", "EE", 149, "K", 75, "angl", 159, "SYMB", 8341, "k", 107},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0xA0, 160 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"(-)", "(-)", 173, " ", 32, "ANS", 4372, "", 8365, " ", 32},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0xB0, 176 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0xC0, 192 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0xD0, 208 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0xE0, 224 */
-  {"", "", 224, "\192", 192, "", 0, "", 0},
-  {"\225", "\225", 225, "\193", 193, "", 0, "", 0},
-  {"", "", 226, "\194", 194, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 228, "\196", 196, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 231, "\199", 199, "", 0, "", 0},
-  {"", "", 232, "\200", 200, "", 0, "", 0},
-  {"", "", 233, "\201", 201, "", 0, "", 0},
-  {"", "", 234, "\202", 202, "", 0, "", 0},
-  {"", "", 235, "\203", 203, "", 0, "", 0},
-  {"\236", "\236", 236, "\204", 204, "", 0, "", 0},
-  {"\237", "\237", 237, "\205", 205, "", 0, "", 0},
-  {"", "", 238, "\206", 206, "", 0, "", 0},
-  {"", "", 239, "\207", 207, "", 0, "", 0},
+  {"\xe0", "\xe0", 224, "\192", 192, "", 0, "", 0, "", 0}, /* agrave */
+  {"\225", "\225", 225, "\193", 193, "", 0, "", 0, "", 0},
+  {"\xe2", "\xe2", 226, "\194", 194, "", 0, "", 0, "", 0}, /* acirc */
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\xe4", "\xe4", 228, "\196", 196, "", 0, "", 0, "", 0}, /* auml */
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\xe7", "\xe7", 231, "\199", 199, "", 0, "", 0, "", 0}, /* ccedil */
+  {"\xe8", "\xe8", 232, "\200", 200, "", 0, "", 0, "", 0}, /* egrave */
+  {"\xe9", "\xe9", 233, "\201", 201, "", 0, "", 0, "", 0}, /* eacute */
+  {"\xea", "\xea", 234, "\202", 202, "", 0, "", 0, "", 0}, /* ecirc */
+  {"\xeb", "\xeb", 235, "\203", 203, "", 0, "", 0, "", 0}, /* euml */
+  {"\236", "\236", 236, "\204", 204, "", 0, "", 0, "", 0},
+  {"\237", "\237", 237, "\205", 205, "", 0, "", 0, "", 0},
+  {"\xee", "\xee", 238, "\206", 206, "", 0, "", 0, "", 0}, /* icirc */
+  {"\xef", "\xef", 239, "\207", 207, "", 0, "", 0, "", 0}, /* iuml */
 /* 0xF0, 240-255 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 241, "\209", 209, "", 0, "", 0},
-  {"\242", "\242", 242, "\210", 210, "", 0, "", 0},
-  {"\243", "\243", 243, "\211", 211, "", 0, "", 0},
-  {"", "", 244, "\212", 212, "", 0, "", 0},
-  {"", "", 245, "", 0, "", 0, "", 0},
-  {"", "", 246, "\214", 214, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 249, "\217", 217, "", 0, "", 0},
-  {"\250", "\250", 250, "\221", 221, "", 0, "", 0},
-  {"", "", 251, "\219", 219, "", 0, "", 0},
-  {"", "", 252, "\220", 220, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 255, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\xf1", "\xf1", 241, "\209", 209, "", 0, "", 0, "", 0}, /* ntilde */
+  {"\242", "\242", 242, "\210", 210, "", 0, "", 0, "", 0},
+  {"\243", "\243", 243, "\211", 211, "", 0, "", 0, "", 0},
+  {"\xf4", "\xf4", 244, "\212", 212, "", 0, "", 0, "", 0}, /* ocirc */
+  {"\xf5", "\xf5", 245, "", 0, "", 0, "", 0, "", 0}, /* otilde */
+  {"\xf6", "\xf6", 246, "\214", 214, "", 0, "", 0, "", 0}, /* ouml */
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\xf9", "\xf9", 249, "\217", 217, "", 0, "", 0, "", 0}, /* ugrave */
+  {"\250", "\250", 250, "\221", 221, "", 0, "", 0, "", 0},
+  {"\xfb", "\xfb", 251, "\219", 219, "", 0, "", 0, "", 0}, /* ucirc */
+  {"\xfc", "\xfc", 252, "\220", 220, "", 0, "", 0, "", 0}, /* uuml */
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"\xff", "\xff", 255, "", 0, "", 0, "", 0, "", 0}, /* yuml */
 /* 0x100, 256 */
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"<-", "BS", 257, "BS", 257, "INS", 4353, "DEL", 8449, "", 0},
   {"STO->", "STO->", 258, "P", 80, "RCL", 4354, "@", 64, "p", 112},
   {"SIN", "SIN", 259, "SIN", 259, "SIN\200", 4355, "", 8451, "", 0},
@@ -322,97 +322,95 @@ const OldCalcKeys_ TI89_KEYS[] =
   {"ESC", "ESC", 264, "ESC", 264, "QUIT", 4360, "", 8456, "", 0},
   {"APPS", "APPS", 265, "APPS", 265, "SWITCH", 4361, "", 8457, "", 0},
   {"MODE", "MODE", 266, "MODE", 266, ">", 18, "_", 95, "MODE", 266 },
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"F1", "F1", 268, "F1", 268, "F1", 8460, "F1", 0},
-  {"F2", "F2", 269, "F2", 269, "F2", 8461, "F2", 0},
-  {"F3", "F3", 270, "F3", 270, "F3", 8462, "F3", 0},
-  {"F4", "F4", 271, "F4", 271, "F4", 8463, "F4", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"F1", "F1", 268, "F1", 268, "F1", 8460, "F1", 0, "", 0},
+  {"F2", "F2", 269, "F2", 269, "F2", 8461, "F2", 0, "", 0},
+  {"F3", "F3", 270, "F3", 270, "F3", 8462, "F3", 0, "", 0},
+  {"F4", "F4", 271, "F4", 271, "F4", 8463, "F4", 0, "", 0},
 /* 0x110,272 */
-  {"F5", "F5", 272, "F5", 272, "F5", 8464, "F5", 268},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"F5", "F5", 272, "F5", 272, "F5", 8464, "F5", 268, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"HOME", "HOME", 277, "HOME", 277, "CUST", 4373, "HOME", 277, "HOME", 277},
-  {"CATLG", "CATLG", 278, "i", 151, "infinite", 190, "CATLG", 278},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"CATLG", "CATLG", 278, "i", 151, "infinite", 190, "CATLG", 278, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0x120, 288 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0x130, 304 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0x140, 320 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0x150, 336 */
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"LEFT", "LEFT", 337, "LEFT", 16721, "LEFT", 4433, "LEFT", 8529},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"LEFT", "LEFT", 337, "LEFT", 16721, "LEFT", 4433, "LEFT", 8529, "", 0},
   {"UP", "UP", 338, "UP", 16722, "UP", 4434, "UP", 8530, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"RIGHT", "RIGHT", 340, "RIGHT", 16724, "RIGHT", 4436, "RIGHT",
-   8532, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
+  {"RIGHT", "RIGHT", 340, "RIGHT", 16724, "RIGHT", 4436, "RIGHT", 8532, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"DOWN", "DOWN", 344, "DOWN", 16728, "DOWN", 4440, "DOWN", 8536, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"DOWN", "DOWN", 344, "DOWN", 16728, "DOWN", 4440, "DOWN", 8536,
-   "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
-  {"", "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0x160 */
 };
