@@ -1,8 +1,8 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: logging.h 1015 2005-05-02 14:00:00Z roms $ */
+/* $Id$ */
 
-/*  libticables - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2005  Romain Lievin
+/*  libticalcs2 - hand-helds support library, a part of the TiLP project
+ *  Copyright (C) 1999-2005  Romain Liévin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,15 +15,15 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __ROMDUMP_H__
 #define __ROMDUMP_H__
 
-int rd_dump(CalcHandle* h, const char *filename);
-int rd_is_ready(CalcHandle* h);
-int rd_send(CalcHandle *h, const char *prgname, unsigned int size, unsigned char *data);
+int rd_dump(CalcHandle* handle, const char *filename);
+int rd_is_ready(CalcHandle* handle);
+int rd_send(CalcHandle *handle, const char *prgname, uint16_t size, uint8_t *data);
 
 #endif
