@@ -14,8 +14,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to the Free Software Foundation,
+ *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #define VERSION		"1.02 USB"			// Version
@@ -34,12 +34,8 @@
 #define CMD_DATA2			0x0007
 #define CMD_NONE			0xffff
 
-typedef unsigned char 			uint8_t;
-typedef unsigned short int  uint16_t;
-typedef unsigned long int		uint32_t;
-
 #define MSB(v)	(v >> 8)
 #define LSB(v)	(v & 0xff)
 
-#define LE_BE(v) (((v & 0xff000000) >> 24) | ((v & 0x00ff0000) >>  8) | ((v & 0x0000ff00) <<  8) | ((v & 0x000000ff) << 24))
+#define LE_BE(v) (((v & 0xff000000) >> 24) | ((v & 0x00ff0000) >> 8) | ((v & 0x0000ff00) << 8) | ((v & 0x000000ff) << 24))
 
